SWDEV-289409 - Add first batch of device tests, add new exe, helper functions and update test Guidelines
Change-Id: I71929caf44725ba2cab7a6f0224bc37b9d04bcbb
This commit is contained in:
@@ -1,6 +1,6 @@
|
||||
#include <hip_test_common.hh>
|
||||
|
||||
TEST_CASE("HostAllocBasic") {
|
||||
TEST_CASE("Unit_hipHostMalloc_4bytes") {
|
||||
int* d_a;
|
||||
auto res = hipHostMalloc(&d_a, sizeof(int), 0);
|
||||
REQUIRE(res == hipSuccess);
|
||||
@@ -8,7 +8,7 @@ TEST_CASE("HostAllocBasic") {
|
||||
REQUIRE(res == hipSuccess);
|
||||
}
|
||||
|
||||
TEST_CASE("AllocateBasic") {
|
||||
TEST_CASE("Unit_hipMalloc_4bytes") {
|
||||
int* d_a;
|
||||
auto res = hipMalloc(&d_a, sizeof(int));
|
||||
REQUIRE(res == hipSuccess);
|
||||
|
||||
@@ -1,6 +1,6 @@
|
||||
#include <hip_test_common.hh>
|
||||
|
||||
TEST_CASE("MemsetBasic") {
|
||||
TEST_CASE("Unit_hipMemset_4bytes") {
|
||||
int* d_a;
|
||||
auto res = hipMalloc(&d_a, sizeof(int));
|
||||
REQUIRE(res == hipSuccess);
|
||||
@@ -9,7 +9,7 @@ TEST_CASE("MemsetBasic") {
|
||||
hipFree(d_a);
|
||||
}
|
||||
|
||||
TEST_CASE("HostMemsetBasic") {
|
||||
TEST_CASE("Unit_hipMemset_4bytes_hostMem") {
|
||||
int* d_a;
|
||||
auto res = hipHostMalloc(&d_a, sizeof(int), 0);
|
||||
REQUIRE(res == hipSuccess);
|
||||
|
||||
Reference in New Issue
Block a user